@@ -91,6 +91,12 @@ class Job(object):
     def properties(self):
         return self._connection.request('/jobs/%s' % self.id)
 
+    @property
+    @cacheable
+    def tags(self):
+        res = self._connection.request('/jobs/%s/tags' % self.id)
+        return [item['name'] for item in res]
+
     @property
     @cacheable
     def units(self):
